function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

var buildDateFromInput = function buildDateFromInput(day, month, year) {
  var date = new Date(Number(year), Number(month) - 1, Number(day));
  return date;
};

var isValidDateObject = function isValidDateObject(date, day, month, year) {
  var isDate = Object.prototype.toString.call(date) === '[object Date]';
  var dayMatch = date.getDate() === Number(day);
  var monthMatch = date.getMonth() === Number(month) - 1;
  var yearMatch = date.getFullYear() === Number(year);
  return isDate && dayMatch && monthMatch && yearMatch;
};

var isValidDate = function isValidDate(day, month, year, props) {
  var userDate = buildDateFromInput(day, month, year);

  if (!isValidDateObject(userDate, day, month, year)) {
    return props.invalidMessage || 'Not a valid date';
  }

  if (props.maxDate) {
    var maxDate = props.maxDate;

    if (userDate > maxDate) {
      var maxDatePlusOne = new Date(maxDate);
      maxDatePlusOne.setDate(maxDatePlusOne.getDate() + 1);
      return props.maxDateMessage || "Date must be less than " + maxDatePlusOne.toDateString().substring(3);
    }
  }

  if (props.minDate) {
    var minDate = props.minDate;

    if (userDate < minDate) {
      var minDateMinusOne = new Date(minDate);
      minDateMinusOne.setDate(minDateMinusOne.getDate() - 1);
      return props.minDateMessage || "Date must be greater than " + minDateMinusOne.toDateString().substring(3);
    }
  }

  return '';
};

var spreadDateToObject = function spreadDateToObject(dateValue) {
  return {
    day: dateValue ? "" + dateValue.getDate() : '',
    month: dateValue ? "" + (dateValue.getMonth() + 1) : '',
    year: dateValue ? "" + dateValue.getFullYear() : ''
  };
};

var flexRow = {
  display: 'flex',
  flexDirection: 'row'
};
var flexColumn = {
  display: 'flex',
  flexDirection: 'column'
};

var InputDatepicker = function InputDatepicker(props) {
  var _useState = React.useState(false),
      hasError = _useState[0],
      setHasError = _useState[1];

  var _useState2 = React.useState(),
      error = _useState2[0],
      setError = _useState2[1];

  var _useState3 = React.useState(spreadDateToObject(props.value)),
      date = _useState3[0],
      setDate = _useState3[1];

  var orderArray = React.useMemo(function () {
    return props.format.split('/');
  }, [props.format]);
  var onDateChange = React.useCallback(function (newDate) {
    props.onDateChange(newDate);
  }, [props]);
  var validDateChange = React.useCallback(function () {
    var newDate = buildDateFromInput(date.day, date.month, date.year);
    onDateChange(newDate);
  }, [date.day, date.month, date.year, onDateChange]);
  var renderError = React.useCallback(function (err, hasErr) {
    setError(err);
    setHasError(hasErr);
    onDateChange(null);
  }, [onDateChange]);
  var validate = React.useCallback(function () {
    var day = date.day,
        month = date.month,
        year = date.year;
    setError('');
    setHasError(false);

    if (!day || !month || !year) {
      onDateChange(null);
      return;
    }

    var errorString = isValidDate(day, month, year, props);

    if (errorString !== '') {
      renderError(errorString, true);
      return;
    }

    validDateChange();
  }, [date, onDateChange, props, renderError, validDateChange]);
  var onInputChange = React.useCallback(function (e) {
    var _extends2;

    setDate(_extends({}, date, (_extends2 = {}, _extends2[e.target.name] = e.target.value, _extends2)));
  }, [date]);
  var inputField = React.useCallback(function (id, label, value) {
    var className = "rid_" + id + "-container";
    return React__default.createElement("div", {
      className: "" + className,
      style: flexColumn
    }, props.showLabels ? React__default.createElement("label", {
      htmlFor: id
    }, label) : null, React__default.createElement("input", {
      className: "" + (hasError ? 'has-error' : ''),
      type: "number",
      id: id,
      name: id,
      value: value,
      onChange: onInputChange,
      onBlur: validate,
      placeholder: props.showPlaceholders ? label : null
    }));
  }, [hasError, onInputChange, props.showLabels, props.showPlaceholders, validate]);
  var dateField = React.useMemo(function () {
    var dayLabel = props.labels && props.labels.day || 'Day';
    var monthLabel = props.labels && props.labels.month || 'Month';
    var yearLabel = props.labels && props.labels.year || 'Year';
    var fields = {
      day: inputField('day', dayLabel, date.day),
      month: inputField('month', monthLabel, date.month),
      year: inputField('year', yearLabel, date.year)
    };
    return fields;
  }, [date.day, date.month, date.year, inputField, props]);
  React.useEffect(function () {
    validate();
  }, []);
  React.useEffect(function () {
    var value = props.value;
    var day = date.day,
        month = date.month,
        year = date.year;

    if (value !== null && value !== buildDateFromInput(day, month, year)) {
      setDate(spreadDateToObject(value));
    }
  }, [props]);
  return React__default.createElement("div", {
    className: "rid " + props.className
  }, React__default.createElement("div", {
    className: "rid_date-container",
    style: flexRow
  }, orderArray.map(function (key, i) {
    return React__default.createElement(React__default.Fragment, {
      key: key + "-" + i
    }, dateField[key]);
  })), props.showErrors && hasError && React__default.createElement("div", {
    className: "error-message"
  }, error));
};
InputDatepicker.defaultProps = {
  value: null,
  showLabels: true,
  showErrors: true,
  showPlaceholders: true,
  format: 'month/day/year',
  className: ''
};

module.exports = InputDatepicker;
//# sourceMappingURL=index.js.map
